@@ -2342,6 +2342,56 @@ pub const DEFAULT_IMAGES: &[&str] = &[
        /|    ^^         \ _ /           is no less
       / |\           -=  ( )  =-      beautiful than
  ~^~ ~=====^~^~-~^~~^~^-=~=~=-~^~^~^~ the sun rising."
+"#,
+    r#"image: |1
+              ___
+            .'   '.__
+           (    o {__)     __  '-.  .'
+            \  ._.'    __.'  '.   '   .-'
+     /\      )  (     (__} o   ) .-')    _
+    |  ``'"'`    \       '.__. /` .'   .'  '
+    \  {`'-       }    (`--')  _.'--`\
+  jgs'. '-._     /      `-.{        _ )
+ ``^^`^`^`^^`^^`^``^`^````^`^^^`^`^^`^^`^^
+"#,
+    r#"image: |1
+          .--.
+        _/aa  \
+       \__\    |
+          )   (      ,
+         /     `-----'\
+        |       --.   |
+      .-\      --'    /-.
+ jgs  `'.-_.-_-,_-._-.-'`
+"#,
+    r#"image: |1
+            ..
+           ( '`<
+            )(
+     ( ----'  '.
+     (         ;
+      (_______,'   jgs
+ ~^~^~^~^~^~^~^~^~^~^~
+"#,
+    r#"image: |1
+  /o>
+ /F)_
+# also seen in the wild like this
+#
+#  /º>
+# /F)_
+"#,
+    r#"image: |1
+               ,
+            _ `|.
+           /o`=|
+    .=""=./::(.=""=.
+   /./.' .::::. \'. \
+  //\/ / :::::: \/\ \\
+ /\/ /\/\'::::'/\ \/\ \
+ /' `     '::'     ` `\
+          /::\
+  jgs    /\/\/\
 "#,
 ];
 
@@ -2360,7 +2410,7 @@ mod tests {
                     eprintln!("Error:{:?}\n\nImage:\n{}", e, i)
                 })
                 .count(),
-            320 // Number of built in images!
+            325 // Number of built in images!
         )
     }
 
